package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Apr 8, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Project struct {
Name string `json:"name"`
Path string `json:"path"`
Branch string `json:"branch"`
Commit string `json:"commit"`
LastUpdated int64 `json:"last_updated"`
SizeBytes int64 `json:"size_bytes"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.